@@ -1,3 +1,9 @@
+##  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ #
+ #  Use of this source code is governed by a BSD-style license that can
+ #  be found in the License.html file in the root of the source tree.
+ ##
+
 #! /bin/sh
 
 #-----------------------------------------------------------------------
@@ -32,6 +38,7 @@ cp ../Project/GNU/GUI/Makefile.am MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
 cp ../Project/GNU/GUI/Makefile.in MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
 cp ../Project/GNU/GUI/missing MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
 cp ../Project/GNU/GUI/wxwin.m4 MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
+cp ../Project/GNU/GUI/mediainfo-gui.appdata.xml MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
 cp ../Project/GNU/GUI/mediainfo-gui.desktop MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
 cp ../Project/GNU/GUI/mediainfo-gui.kde3.desktop MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
 cp ../Project/GNU/GUI/mediainfo-gui.kde4.desktop MediaInfo_GUI_GNU_FromSource/Project/GNU/GUI/
@@ -50,10 +57,11 @@ cp -r ../Source/GUI/Common/*.cpp MediaInfo_GUI_GNU_FromSource/Source/GUI/Common/
 mkdir -p MediaInfo_GUI_GNU_FromSource/Source/GUI/WxWidgets
 cp -r ../Source/GUI/WxWidgets/*.h MediaInfo_GUI_GNU_FromSource/Source/GUI/WxWidgets/
 cp -r ../Source/GUI/WxWidgets/*.cpp MediaInfo_GUI_GNU_FromSource/Source/GUI/WxWidgets/
-mkdir -p MediaInfo_GUI_GNU_FromSource/Source/Ressource/Image/Menu
-cp -r ../Source/Ressource/Image/*.png MediaInfo_GUI_GNU_FromSource/Source/Ressource/Image/
-cp -r ../Source/Ressource/Image/*.xpm MediaInfo_GUI_GNU_FromSource/Source/Ressource/Image/
-cp -r ../Source/Ressource/Image/Menu/*.xpm MediaInfo_GUI_GNU_FromSource/Source/Ressource/Image/Menu/
+mkdir -p MediaInfo_GUI_GNU_FromSource/Source/Resource/Image/Menu/K20
+cp -r ../Source/Resource/Image/*.png MediaInfo_GUI_GNU_FromSource/Source/Resource/Image/
+cp -r ../Source/Resource/Image/*.xpm MediaInfo_GUI_GNU_FromSource/Source/Resource/Image/
+cp -r ../Source/Resource/Image/*.icns MediaInfo_GUI_GNU_FromSource/Source/Resource/Image/
+cp -r ../Source/Resource/Image/Menu/K20/*.xpm MediaInfo_GUI_GNU_FromSource/Source/Resource/Image/Menu/K20/
 
 #-----------------------------------------------------------------------
 # Copying : Release
